@@ -1,14 +1,16 @@
 import itertools
+from functools import partial
+
 
 identity = lambda x: x
 
+
 def remove(predicate, coll):
     """ Return those items of collection for which predicate(item) is true.
 
-    >>> from itertoolz import remove
     >>> def even(x):
     ...     return x % 2 == 0
-    >>> remove(even, [1, 2, 3, 4])
+    >>> list(remove(even, [1, 2, 3, 4]))
     [1, 3]
     """
     return filter(lambda x: not predicate(x), coll)
@@ -17,7 +19,6 @@ def remove(predicate, coll):
 def groupby(f, coll):
     """ Group a collection by a key function
 
-    >>> from itertoolz import groupby
     >>> names = ['Alice', 'Bob', 'Charlie', 'Dan', 'Edith', 'Frank']
     >>> groupby(len, names)
     {3: ['Bob', 'Dan'], 5: ['Alice', 'Edith', 'Frank'], 7: ['Charlie']}
@@ -30,11 +31,11 @@ def groupby(f, coll):
         d[key].append(item)
     return d
 
-from Queue import PriorityQueue
+
+from itertoolz.compatibility import Queue
 def merge_sorted(*iters, **kwargs):
     """ Merge and sort a collection of sorted collections
 
-    >>> from itertoolz import merge_sorted
     >>> list(merge_sorted([1, 3, 5], [2, 4, 6]))
     [1, 2, 3, 4, 5, 6]
 
@@ -43,29 +44,29 @@ def merge_sorted(*iters, **kwargs):
     """
     key = kwargs.get('key', identity)
     iters = map(iter, iters)
-    pq = PriorityQueue()
+    pq = Queue.PriorityQueue()
 
-    def inject_first_element(it):
+    def inject_first_element(it, tiebreaker=None):
         try:
             item = next(it)
-            pq.put((key(item), item, it))
+            pq.put((key(item), item, tiebreaker, it))
         except StopIteration:
             pass
 
     # Initial population
-    for it in iters:
-        inject_first_element(it)
+    for i, it in enumerate(iters):
+        inject_first_element(it, i)
 
     # Repeatedly yield and then repopulate from the same iterator
     while not pq.empty():
-        _, item, it = pq.get()
+        _, item, tb, it = pq.get()
         yield item
-        inject_first_element(it)
+        inject_first_element(it, tb)
+
 
 def merge_dict(*dicts):
     """ Merge a collection of dictionaries
 
-    >>> from itertoolz import merge_dict
     >>> merge_dict({1: 'one'}, {2: 'two'})
     {1: 'one', 2: 'two'}
 
@@ -79,10 +80,10 @@ def merge_dict(*dicts):
         rv.update(d)
     return rv
 
+
 def interleave(seqs, pass_exceptions=()):
     """ Interleave a sequence of sequences
 
-    >>> from itertoolz import interleave
     >>> list(interleave([[1, 2], [3, 4]]))
     [1, 3, 2, 4]
 
@@ -93,7 +94,7 @@ def interleave(seqs, pass_exceptions=()):
 
     Returns a lazy iterator
     """
-    iters = itertools.imap(iter, seqs)
+    iters = map(iter, seqs)
     while iters:
         newiters = []
         for itr in iters:
@@ -108,7 +109,6 @@ def interleave(seqs, pass_exceptions=()):
 def unique(seq, key=identity):
     """ Return only unique elements of a sequence
 
-    >>> from itertoolz import unique
     >>> tuple(unique((1, 2, 3)))
     (1, 2, 3)
     >>> tuple(unique((1, 2, 1, 3)))
@@ -116,10 +116,8 @@ def unique(seq, key=identity):
 
     Uniqueness can be defined by key keyword
 
-    >>> def mod_10(x):
-    ...     return x % 10
-    >>> tuple(unique((5, 10, 15, 18, 20, 38), key=mod_10))
-    (5, 10, 18)
+    >>> tuple(unique(['cat', 'mouse', 'dog', 'hen'], key=len))
+    ('cat', 'mouse')
     """
     seen = set()
     for item in seq:
@@ -132,7 +130,6 @@ def unique(seq, key=identity):
 def intersection(*seqs):
     """ Lazily evaluated intersection of sequences
 
-    >>> from itertoolz import intersection
     >>> list(intersection([1, 2, 3], [2, 3, 4]))
     [2, 3]
     """
@@ -142,7 +139,6 @@ def intersection(*seqs):
 def iterable(x):
     """ Is x iterable?
 
-    >>> from itertoolz import iterable
     >>> iterable([1, 2, 3])
     True
     >>> iterable('abc')
@@ -156,10 +152,10 @@ def iterable(x):
     except TypeError:
         return False
 
+
 def distinct(seq):
     """ All values in sequence are distinct
 
-    >>> from itertoolz import distinct
     >>> distinct([1, 2, 3])
     True
     >>> distinct([1, 2, 1])
@@ -171,3 +167,59 @@ def distinct(seq):
     True
     """
     return len(seq) == len(set(seq))
+
+def take(n, seq):
+    """ The first n elements of a sequence
+
+    >>> list(take(2, [10, 20, 30, 40, 50]))
+    [10, 20]
+    """
+    return itertools.islice(seq, n)
+
+def drop(n, seq):
+    """ The sequence following the first n elements
+
+    >>> list(drop(2, [10, 20, 30, 40, 50]))
+    [30, 40, 50]
+    """
+    return itertools.islice(seq, n, None)
+
+def first(seq):
+    """ The first element in a sequence
+
+    >>> first('ABC')
+    'A'
+    """
+    return next(iter(seq))
+
+def nth(n, seq):
+    """ The nth element in a sequence
+
+    >>> nth(1, 'ABC')
+    'B'
+    """
+    try:
+        return seq[n]
+    except TypeError:
+        return next(itertools.islice(seq, n, None))
+
+def last(seq):
+    """ The last element in a sequence
+
+    >>> last('ABC')
+    'C'
+    """
+    try:
+        return seq[-1]
+    except TypeError:
+        old = None
+        it = iter(seq)
+        while True:
+            try:
+                old = next(it)
+            except StopIteration:
+                return old
+
+
+second = partial(nth, 1)
+rest = partial(drop, 1)
